const app = getApp()
import {
    Base
} from '../../../utils/base.js';
const base = new Base()
const util = require('../../../utils/util');
Page({

    /**
     * 页面的初始数据
     */
    data: {
        coach_id: '',
        isOpen: false,
        daysColor: [],
        today: '', // 今天日期
        curDate: '',
        list: [],
        allList: [],
        month: '',
        calendarConfig: {
            multi: true, // 是否开启多选,
            weekMode: false, // 周视图模式
            theme: 'elegant', // 日历主题，目前共两款可选择，默认 default 及 elegant，自定义主题色在参考 /theme 文件夹
            inverse: true, // 单选模式下是否支持取消选中,
            markToday: '今', // 当天日期展示不使用默认数字，用特殊文字标记
            takeoverTap: false, // 是否完全接管日期点击事件（日期不会选中)
            emphasisWeek: true, // 是否高亮显示周末日期
            chooseAreaMode: false, // 开启日期范围选择模式，该模式下只可选择时间段
            preventSwipe: true, // 是否禁用日历滑动切换月份
            onlyShowCurrentMonth: true, // 日历面板是否只显示本月日期
        }
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        wx.showLoading({
            title: '加载中...',
        })
        let year = new Date().getFullYear()
        let month = util.formatNumber(new Date().getMonth() + 1)
        this.setData({
            coach_id: app.globalData.coach_id,
            today: util.formatTime(new Date()),
            curDate: util.formatTime(new Date()),
            month: year + month
        })
        this.getAllList()
        this.getList()
    },
    getAllList() {
        wx.showLoading({
            title: '加载中...',
        })
        let params = {
            url: 'coach/timetable',
            data: {
                coach_id: this.data.coach_id,
                month: this.data.month
            },
            callback: (data) => {
                wx.hideLoading()
                this.setData({
                    allList: data
                })
                this.afterCalendarRender()
            }
        }
        base.newRequest(params)
    },
    getList() {
        let params = {
            url: 'coach/schedule',
            data: {
                coach_id: this.data.coach_id,
                date: this.data.curDate
            },
            callback: (data) => {
                this.setData({
                    list: data,
                    locked: false
                })
            }
        }
        base.newRequest(params)
    },

    
    afterCalendarRender(e) {
        let daysColor = [];
        this.data.allList.forEach(function (el) {
            daysColor.push({
                year: el.class_date.split('-')[0],
                month: el.class_date.split('-')[1],
                date: el.class_date.split('-')[2],
                class: 'circle_data'
            })
        })
        const calendar = this.selectComponent('#calendar').calendar
        calendar.setDateStyle(daysColor)
    },
    afterTapDate(e) {
        const calendar = this.selectComponent('#calendar').calendar
        calendar.cancelSelectedDates()
        this.setData({
            curDate: e.detail.year + '-' + util.formatNumber(e.detail.month) + '-' + util.formatNumber(e.detail.date)
        })
        const toSet = [
            {
              year: e.detail.year,
              month: e.detail.month,
              date: e.detail.date,
              class: 'orange-date' // 页面定义的 class，多个 class 由空格隔开
            }
        ]
        calendar.setSelectedDates(toSet)
        if (!this.data.locked) {
            this.setData({
                locked: true,
                courseList: [],
            })
            this.getList();
        }
    },
    whenChangeMonth(e) {
        let currentMonth = util.formatNumber(e.detail.next.month)
        this.setData({
            month: e.detail.next.year + currentMonth
        })
        this.getAllList();
    },
    // prev: function (event) {
    //     let currentMonth = util.formatNumber(event.detail.currentMonth)
    //     this.setData({
    //         month: event.detail.currentYear + currentMonth
    //     })
    //     this.getAllList();
    // },
    // next: function (event) {
    //     let currentMonth = util.formatNumber(event.detail.currentMonth)
    //     this.setData({
    //         month: event.detail.currentYear + currentMonth
    //     })
    //     this.getAllList();
    // },
    // dayClick: function (event) {
    //     console.log(event)
    //     this.setData({
    //         curDate: event.detail.year + '-' + util.formatNumber(event.detail.month) + '-' + util.formatNumber(event.detail.day)
    //     })
    //     if (!this.data.locked) {
    //         this.setData({
    //             locked: true,
    //             courseList: [],
    //         })
    //         this.getList();
    //     }
    // },

    onChange(e) {
        let index = e.currentTarget.dataset.index
        let list = this.data.classlist
        list[index].timeData = e.detail
        this.setData({
            classlist: list
        })
    },
    changeTab(e) {
        let index = e.currentTarget.dataset.index
        if (this.data.activeIndex != index) {
            this.setData({
                activeIndex: index
            })
        }
    },
    // 日历展开与否
    open() {
        this.setData({
            isOpen: !this.data.isOpen
        })
    },
    goclassManagement: function (e) {
        let item = e.currentTarget.dataset.item
        let classTime = this.data.curDate + ' ' + item.start_time + '～' + item.end_time
        wx.navigateTo({
            url: '/pages/index/classManagement/classManagement?classTime=' + classTime + '&class_id=' + item.class_id + '&lesson_id=' + item.id,
        })
    },
    goDetail(e) {
        let item = e.currentTarget.dataset.item
        wx.navigateTo({
            url: '/pages/index/classDetail/classDetail?class_id=' + item.class_id + '&lesson_id=' + item.id,
        })
    },
})